@@ -493,7 +493,7 @@ class WrapperBase(metaclass=Metaclass):
 
         # return  _sin.schema_json()
         sc = AIschema(meta=MetaModel(), schemainput=SchemaInputModel(), schemaoutput=OutputModel(),
-                      is_aipaas=self.is_aipaas,keep_default=self.keep_schema_default_value)
+                      is_aipaas=self.is_aipaas, keep_default=self.keep_schema_default_value)
         log.info("Generating V2 Schema....")
         return json.dumps(sc.json())
 
@@ -912,13 +912,18 @@ class WrapperBase(metaclass=Metaclass):
             if not isinstance(d.data, memoryview) and not isinstance(d.data, bytes):
                 log.error("ResponseData 's data field must be  bytes or memoryview")
                 return False
+            if d.len != len(d.data):
+                log.error(
+                    "ResponseData: key: %s 's len is mismatch,Please Check! expect %d, actual: %d" % (
+                    d.key, d.len, len(d.data)))
+                return False
 
         # check 响应key是否重复
         keys = [r.key for r in resp.list]
         set_keys = set(keys)
         log.info("response keys: %s", str(keys))
         if not len(keys) == len(set_keys):
-            log.error("response list keys must be unique...")
+            log.error("response list keys must be u nique...")
             log.error("invalid keys %s" % str(keys))
             return False
 
