@@ -31,10 +31,45 @@
 #  Proin dapibus sapien vel ante. Aliquam erat volutpat. Pellentesque sagittis ligula eget metus.
 #  Vestibulum commodo. Ut rhoncus gravida arcu.
 import logging
+import os
+
+fmt = '%(asctime)s - %(name)s:%(funcName)s:%(lineno)s - %(levelname)s:  %(message)s'
+level = logging.DEBUG
 ch = logging.StreamHandler()
-formatter = logging.Formatter('%(asctime)s - %(name)s - %(levelname)s - %(message)s')
+formatter = logging.Formatter(fmt)
 ch.setFormatter(formatter)
 ch.setLevel(logging.INFO)
 log = logging.getLogger()
-log.setLevel(logging.DEBUG)
-log.addHandler(ch)
\ No newline at end of file
+log.setLevel(level)
+log.addHandler(ch)
+
+logpath = "/log/app"
+
+
+def getLogger(fmt=fmt, level=level, name="root"):
+    global log
+    ch = logging.StreamHandler()
+    formatter = logging.Formatter(fmt)
+    ch.setFormatter(formatter)
+    ch.setLevel(logging.INFO)
+    log.setLevel(level)
+    for handler in log.handlers:
+        log.removeHandler(handler)
+    log.addHandler(ch)
+    return log
+
+
+def getFileLogger(fmt=fmt, level=level, name="python_wrapper"):
+    log = logging.getLogger(name)
+    if not os.path.isdir(logpath) or not os.path.exists(logpath):
+        os.makedirs(logpath)
+
+    lfname = os.path.join(logpath, name + ".log")
+    ch = logging.FileHandler(lfname)
+    formatter = logging.Formatter(fmt)
+    ch.setFormatter(formatter)
+    ch.setLevel(level)
+    for handler in log.handlers:
+        log.removeHandler(handler)
+    log.addHandler(ch)
+    return log
